# ZeskaLang
Tanglish-based beginner-friendly programming language (auto-correct + self-heal)
# 🌀 ZeskaLang

[![PyPI version](https://img.shields.io/pypi/v/zeska-lang.svg)](https://pypi.org/project/zeska-lang/)
[![License](https://img.shields.io/github/license/Smartsibi65hacker/ZeskaLang.svg)](https://github.com/Smartsibi65hacker/ZeskaLang/blob/main/LICENSE)
[![Downloads](https://img.shields.io/pypi/dm/zeska-lang.svg)](https://pypi.org/project/zeska-lang/)

Tanglish-based beginner-friendly programming language that auto-corrects and self-heals.

---

### ⚙️ Installation
```bash
pip install zeska-lang
